#
# spec file for package perl-CHI
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name CHI
Name:           perl-CHI
Version:        0.61
Release:        1.14
Summary:        Unified cache handling interface
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AS/ASB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Cache::FileCache)
BuildRequires:  perl(Carp::Assert) >= 0.20
BuildRequires:  perl(Class::Load)
BuildRequires:  perl(Data::UUID)
BuildRequires:  perl(Date::Parse)
BuildRequires:  perl(Digest::JHash)
BuildRequires:  perl(Hash::MoreUtils)
BuildRequires:  perl(JSON::MaybeXS) >= 1.003003
BuildRequires:  perl(List::MoreUtils) >= 0.13
BuildRequires:  perl(Log::Any) >= 0.08
BuildRequires:  perl(Module::Mask)
BuildRequires:  perl(Moo) >= 1.003
BuildRequires:  perl(MooX::Types::MooseLike) >= 0.23
BuildRequires:  perl(MooX::Types::MooseLike::Base)
BuildRequires:  perl(MooX::Types::MooseLike::Numeric)
BuildRequires:  perl(String::RewritePrefix)
BuildRequires:  perl(Task::Weaken)
BuildRequires:  perl(Test::Class)
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Exception)
BuildRequires:  perl(Test::Warn)
BuildRequires:  perl(Time::Duration) >= 1.060000
BuildRequires:  perl(Time::Duration::Parse) >= 0.03
BuildRequires:  perl(Try::Tiny) >= 0.05
Requires:       perl(Carp::Assert) >= 0.20
Requires:       perl(Class::Load)
Requires:       perl(Data::UUID)
Requires:       perl(Digest::JHash)
Requires:       perl(Hash::MoreUtils)
Requires:       perl(JSON::MaybeXS) >= 1.003003
Requires:       perl(List::MoreUtils) >= 0.13
Requires:       perl(Log::Any) >= 0.08
Requires:       perl(Moo) >= 1.003
Requires:       perl(MooX::Types::MooseLike) >= 0.23
Requires:       perl(MooX::Types::MooseLike::Base)
Requires:       perl(MooX::Types::MooseLike::Numeric)
Requires:       perl(String::RewritePrefix)
Requires:       perl(Task::Weaken)
Requires:       perl(Time::Duration) >= 1.060000
Requires:       perl(Time::Duration::Parse) >= 0.03
Requires:       perl(Try::Tiny) >= 0.05
%{perl_requires}

%description
CHI provides a unified caching API, designed to assist a developer in
persisting data for a specified period of time.

The CHI interface is implemented by driver classes that support fetching,
storing and clearing of data. Driver classes exist or will exist for the
gamut of storage backends available to Perl, such as memory, plain files,
memory mapped files, memcached, and DBI.

CHI is intended as an evolution of DeWitt Clinton's Cache::Cache package,
adhering to the basic Cache API but adding new features and addressing
limitations in the Cache::Cache implementation.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes
%license LICENSE

%changelog
* Thu Oct 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.61
  see /usr/share/doc/packages/perl-CHI/Changes
* Sun Sep 20 2015 coolo@suse.com
- updated to 0.60
  see /usr/share/doc/packages/perl-CHI/Changes
  0.60  Jun 7, 2015
  * Fixes
  - Switch JSON backends from JSON.pm to JSON::MaybeXS - https://github.com/jonswar/perl-chi/pull/20 (Karen Etheridge)
* Fri Apr 24 2015 coolo@suse.com
- fix requires to Time::Duration
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.59
  see /usr/share/doc/packages/perl-CHI/Changes
* Wed Jul 24 2013 coolo@suse.com
- updated to 0.58
  * Fixes
  - Fix busted packaging
  0.57  July 21, 2013
  * Implementation
  - Use Moo instead of Moose for object system.  This should be fully compatible
    with existing code, including Moose drivers or other extensions.  This
    reduces the startup time and memory overhead.
  * Fixes
  - Fix the loading of additional roles or traits (jrouzierinverse)
* Wed May 15 2013 coolo@suse.com
- updated to 0.56
  * Fixes
  - Mention testing_driver_class in CHI/Driver/Development.pm - RT #78921 (Nigel Horne)
  * Tests
  - Add test_multiple_processes for testing drivers under concurrent writes - RT #79132 (Nigel Horne)
  * Docs
  - Mention that driver tests are responsible for their own cleanup - RT #79100 (Nigel Horne)
  - Various spelling fixes thanks to Pod::Spell
  * Improvements
  - Compute derived/aggregate stats in CHI::Stats::parse_stats_logs
  * Fixes
  - Eliminate "=for html" POD entries, which were mangling metacpan.org output (Pedro Melo)
  * * Incompatible Changes **
  - ** Switch CHI::Stats format to JSON for easier generation and parsing
  * Improvements
  - Measure time elapsed in get, set, and compute; record in logs and stats. Only
    measure when debug logging or stats are enabled.
  - compute() now handles list or scalar caller context
  - The driver parameter now accepts full classes prefixed by '+', as is standard.
    driver_class is still accepted for backward compatibility but no longer documented.
  * Fixes
  - compute() no longer modifies passed-in options hashref
  - Fix get_multi_* with partially empty l1 cache - perl-chi/pull/12 (Mike Cartmell)
  - Fix get_keys when file_extension set on CHI::Driver::File - RT #76489 (Vitaliy Tokarev)
  - Have set_multi call store_multi underneath as documented in Development.pod - RT
    [#76621] (Oliver Paukstadt)
  - Minor POD fixes (Alessandro Ghedini)
* Mon Mar 12 2012 tabraham@novell.com
- updated to 0.52
  - Subclasses inherit configuration from their parents unless they
    also call config()
  - Fix Config test to not require memcached
- changes from 0.51
  - add CHI->config() to register storage types, and set core and
    per-namespace defaults
  - fix new test_max_key_length test to work on drivers that do not
    support get_keys
* Wed Feb 15 2012 tabraham@novell.com
- updated to 0.50
  - Clarify busy_lock doc, add obj_ref doc (perlover)
  - Override set() rather than set_object() in Role/HasSubcaches.pm
    so that keys are not double-transformed when set in l1 or mirror
    caches. This is simpler and should be more robust.
  - Remove htdocs which were accidentally added into dist
* Tue Oct 25 2011 tabraham@novell.com
- updated to 0.49
  - go back to generating version numbers for all sub-modules again
- updated to 0.48
  - disregard default expires_at and expires_in if either are provided
    RT #67970 (spjw)
* Fri Apr 29 2011 coolo@opensuse.org
- updated to 0.47
  * Improvements
  - Allow compute() to take get options - expire_if and busy_lock
  - Add atomic operations: add, append, replace (alpha)
* Wed Apr 27 2011 coolo@opensuse.org
- updated to 0.46
  - Only generate version numbers for .pm files with documentation, to reduce inter-version churn
  - Add expires_on_backend parameter
* Sun Apr  3 2011 coolo@novell.com
- updated to 0.44
  * Fixes
  - Remove more unnecessary packages from CPAN index
  - Put parens around qw in various places to fix for perl 5.13+
  * Improvements
  - Add compress_threshold parameter
  - Improve accuracy of benchmarks (nothingmuch)
- for more see Changes
* Fri Jan 14 2011 coolo@novell.com
- initial package 0.36
  * created by cpanspec 1.78.03
